@@ -16,18 +16,17 @@
 #define _KGPGEXTERNALACTIONS_H
 
 #include <QObject>
-#include <QClipboard>
 #include <QPointer>
 #include <QStringList>
 
-#include <KUrl>
+#include <QUrl>
 
 class KeysManager;
 class KGpgFirstAssistant;
 class KGpgItemModel;
 class KJob;
-class KShortcut;
-class KTemporaryFile;
+class QKeySequence;
+class QTemporaryFile;
 class QString;
 
 /**
@@ -44,21 +43,23 @@ public:
 	KGpgExternalActions(KeysManager *parent, KGpgItemModel *model);
 	~KGpgExternalActions();
 
-	void showDroppedFile(const KUrl &file);
-	void verifyFile(KUrl url);
+	void showDroppedFile(const QUrl &file);
+	void verifyFile(QUrl url);
 
 	/**
 	 * @brief create a detached signature for the given files
 	 */
-	static void signFiles(KeysManager* parent, const KUrl::List &urls);
+	static void signFiles(KeysManager* parent, const QList<QUrl> &urls);
 
-	static void decryptFiles(KeysManager* parent, const KUrl::List& urls);
-	static void encryptFolders(KeysManager* parent, const KUrl::List &urls);
+	static void decryptFiles(KeysManager* parent, const QList<QUrl>& urls);
+	static void encryptFolders(KeysManager* parent, const QList<QUrl> &urls);
 
 	/**
 	 * @brief create a new object, encrypt the given files, and destroy the object
 	 */
-	static void encryptFiles(KeysManager* parent, const KUrl::List& urls);
+	static void encryptFiles(KeysManager* parent, const QList<QUrl>& urls);
+
+	void readOptions();
 signals:
 	void createNewKey();
 	void updateDefault(QString);
@@ -67,26 +68,24 @@ private:
 	QStringList customDecrypt;
 	QPointer<KGpgFirstAssistant> m_assistant;
 	int compressionScheme;
-	QClipboard::Mode clipboardMode;
 	KGpgItemModel *m_model;
-	KTemporaryFile *m_kgpgfoldertmp;
+	QTemporaryFile *m_kgpgfoldertmp;
 
 	void startAssistant();
 	void firstRun();
 
-	KUrl::List m_decryptionFailed;
+	QList<QUrl> m_decryptionFailed;
 	KeysManager *m_keysmanager;
-	KUrl::List droppedUrls;
+	QList<QUrl> droppedUrls;
 
-	KShortcut goDefaultKey() const;
-	void decryptFile(KUrl::List urls);
+	QKeySequence goDefaultKey() const;
+	void decryptFile(QList<QUrl> urls);
 
 private slots:
 	void startFolderEncode();
 	void slotSaveOptionsPath();
 	void slotVerificationDone(int result);
 	void help();
-	void readOptions();
 	void slotSetCompression(int cp);
 	void slotDecryptionDone(int status);
 	void slotFolderFinished(KJob *job);
