@@ -45,12 +45,3 @@ KGpgChangeDisable::preStart()
 
 	return true;
 }
-
-bool
-KGpgChangeDisable::nextLine(const QString &line)
-{
-	if(keyConsidered(line, QStringList(getKeyid())))
-		return false;
-
-	return KGpgEditKeyTransaction::nextLine(line);
-}
